@@ -18,19 +18,12 @@ r = ki.OfflineReader(data_path("offline/usr-sample.root"))
 
 
 #####################################################
-# Accessing the usr data:
+# Accessing the usr fields:
 
-usr = r.events.usr
-print(usr)
+print(r.events.usr_names.tolist())
 
 
 #####################################################
-# to access data of a specific key, you can either do:
+# to access data of a specific key:
 
-print(usr.DeltaPosZ)
-
-
-#####################################################
-# or
-
-print(usr['RecoQuality'])
+print(ki.tools.usr(r.events, "DeltaPosZ"))
